summaryrefslogtreecommitdiffstats
path: root/lib/util/filetemplate.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/filetemplate.h')
-rw-r--r--lib/util/filetemplate.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/util/filetemplate.h b/lib/util/filetemplate.h
index f179f5be..b1ba2cdc 100644
--- a/lib/util/filetemplate.h
+++ b/lib/util/filetemplate.h
@@ -20,7 +20,7 @@
#ifndef _FILETEMPLATE_H_
#define _FILETEMPLATE_H_
-#include <qstring.h>
+#include <tqstring.h>
class KDevPlugin;
class QDomDocument;
@@ -49,40 +49,40 @@ public:
* exists in the current project. File templates
* are stored in the "templates" subdirectory of a project or in application shared dirs.
*/
- static bool exists(KDevPlugin *part, const QString &name, Policy p = Default);
+ static bool exists(KDevPlugin *part, const TQString &name, Policy p = Default);
/**
* Reads a template with the given name (e.g. "cpp")
* and makes variable substitutions (like $AUTHOR$ etc.)
* in it. The resulting string is returned.
*/
- static QString read(KDevPlugin *part, const QString &name, Policy p = Default);
+ static TQString read(KDevPlugin *part, const TQString &name, Policy p = Default);
/**
* Reads a template with the given URL
* and makes variable substitutions (like $AUTHOR$ etc.)
* in it. The resulting string is returned.
*/
- static QString readFile(KDevPlugin *part, const QString &fileName);
+ static TQString readFile(KDevPlugin *part, const TQString &fileName);
/**
* Makes variable substitutions on a text, based on a specified QDomDocument
* describing a KDevelop project file. The resulting string is returned.
*/
- static QString makeSubstitutions(QDomDocument &dom, const QString &text);
+ static TQString makeSubstitutions(TQDomDocument &dom, const TQString &text);
/**
* Copies a file template with the given name to the
* file with the name dest and - while copying -
* performs variable substitutions.
*/
- static bool copy(KDevPlugin *part, const QString &name,
- const QString &dest, Policy p = Default);
+ static bool copy(KDevPlugin *part, const TQString &name,
+ const TQString &dest, Policy p = Default);
/**
* Translates a template name into a full path, or suggests a full path
* for the template in the project directory if it doesn't exist.
*/
- static QString fullPathForName(KDevPlugin *part, const QString &name, Policy p = Default);
+ static TQString fullPathForName(KDevPlugin *part, const TQString &name, Policy p = Default);
};
#endif
@@ -49,40 +49,40 @@ public:
/**
- * Makes variable substitutions on a text, based on a specified QDomDocument
+ * Makes variable substitutions on a text, based on a specified TQDomDocument
* describing a KDevelop project file. The resulting string is returned.
*/